
# Slot: conforms_to


An established standard to which the element conforms.

URI: [linkml:conforms_to](https://w3id.org/linkml/conforms_to)


## Domain and Range

[Element](Element.md) &#8594;  <sub>0..1</sub> [String](types/String.md)

## Parents


## Children


## Used by

 * class_definition
 * definition
 * [Element](Element.md)
 * enum_definition
 * schema_definition
 * slot_definition
 * subset_definition
 * type_definition

## Other properties

|  |  |  |
| --- | --- | --- |
| **Mappings:** | | dcterms:conformsTo |

